@@ -1,5 +1,5 @@
 #
-# $Id: Splunk.pm,v 629ac2fb6bcb 2016/02/13 17:10:24 gomor $
+# $Id: Splunk.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
 #
 # api::splunk Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Rest);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 629ac2fb6bcb $',
+      revision => '$Revision: f6ad8c136b19 $',
       tags => [ qw(unstable rest) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -20,7 +20,7 @@ sub brik_properties {
          username => [ qw(username) ],  # Inherited
          password => [ qw(password) ],  # Inherited
          ssl_verify => [ qw(0|1) ], # Inherited
-         output_mode => [ qw(json|xml) ],
+         output_mode => [ qw(json|xml|csv) ],
          count => [ qw(number) ],
          offset => [ qw(number) ],
       },
@@ -28,17 +28,24 @@ sub brik_properties {
          uri => 'https://localhost:8089',
          username => 'admin',
          ssl_verify => 0,
-         output_mode => 'xml',
+         output_mode => 'json',
          count => 1000,  # 0 means return everything
          offset => 0,  # 0 means return everything
       },
       commands => {
+         get => [ qw(path) ],
          reset_user_agent => [ ],  # Inherited
          apps_local => [ ],
          search_jobs => [ qw(search) ],
          search_jobs_sid => [ qw(sid) ],
          search_jobs_sid_results => [ qw(sid count|OPTIONAL offset|OPTIONAL) ],
          licenser_groups => [ ],
+         data_lookup_table_files_acl => [ qw(app csv_file perm|OPTIONAL) ],
+         cluster_config => [ ],
+         cluster_config_config => [ ],
+         deployment_client => [ ],
+         deployment_client_config => [ ],
+         search_data_lookuptablefiles => [ qw(username|OPTIONAL) ],
       },
    };
 }
@@ -48,36 +55,43 @@ sub brik_properties {
 # http://docs.splunk.com/Documentation/Splunk/latest/RESTREF/RESTlist
 #
 
-sub apps_local {
+sub get {
    my $self = shift;
+   my ($path, $count) = @_;
+
+   $count ||= $self->count;
+   $self->brik_help_run_undef_arg('get', $path) or return;
 
    my $uri = $self->uri;
-   $self->brik_help_set_undef_arg('apps_local', $uri) or return;
 
-   $self->get($uri.'/services/apps/local') or return;
+   my $resp = $self->SUPER::get($uri.$path.'?count='.$count) or return;
 
-   my $content = $self->content or return;
+   my $content = $self->content('xml') or return;
    my $code = $self->code or return;
 
-   $self->log->verbose("apps_local: returned code [$code]");
-   $self->debug && $self->log->debug("apps_local: content [$content]");
+   $self->log->verbose("get: returned code [$code]");
 
    return $content;
 }
 
+sub apps_local {
+   my $self = shift;
+
+   return $self->get('/services/apps/local');
+}
+
 #
-# Example:
 # run api::splunk search_jobs "{ search => 'search index=main' }" https://localhost:8089
 #
 sub search_jobs {
    my $self = shift;
    my ($post) = @_;
 
-   my $uri = $self->uri;
-   $self->brik_help_set_undef_arg('search_jobs', $uri) or return;
    $self->brik_help_run_undef_arg('search_jobs', $post) or return;
    $self->brik_help_run_invalid_arg('search_jobs', $post, 'HASH') or return;
 
+   my $uri = $self->uri;
+
    my $resp = $self->post($post, $uri.'/services/search/jobs') or return;
 
    my $code = $self->code;
@@ -86,7 +100,7 @@ sub search_jobs {
    $self->debug && $self->log->debug("search_jobs: content [".$resp->{content}."]");
 
    if ($code == 201) {  # Job created
-      return $self->content;
+      return $self->content('xml');
    }
 
    return $self->log->error("search_jobs: failed with code [$code]");
@@ -96,11 +110,11 @@ sub search_jobs_sid {
    my $self = shift;
    my ($sid) = @_;
 
-   my $uri = $self->uri;
-   $self->brik_help_set_undef_arg('search_jobs_sid', $uri) or return;
    $self->brik_help_run_undef_arg('search_jobs_sid', $sid) or return;
 
-   my $resp = $self->get($uri.'/services/search/jobs/'.$sid) or return;
+   my $uri = $self->uri;
+
+   my $resp = $self->SUPER::get($uri.'/services/search/jobs/'.$sid) or return;
 
    my $code = $self->code;
 
@@ -111,7 +125,7 @@ sub search_jobs_sid {
       return 0;
    }
    elsif ($code == 200) {
-      return $self->content;
+      return $self->content('xml');
    }
 
    return $self->log->error("search_jobs_sid: failed with code [$code]");
@@ -124,15 +138,16 @@ sub search_jobs_sid_results {
    my $self = shift;
    my ($sid, $count, $offset) = @_;
 
-   my $uri = $self->uri;
    $count ||= $self->count;
    $offset ||= $self->offset;
-   $self->brik_help_set_undef_arg('search_jobs_sid_results', $uri) or return;
    $self->brik_help_run_undef_arg('search_jobs_sid_results', $sid) or return;
 
-   my $resp = $self->get(
+   my $uri = $self->uri;
+   my $output_mode = $self->output_mode;
+
+   my $resp = $self->SUPER::get(
       $uri.'/services/search/jobs/'.$sid.
-      "/results/?output_mode=csv&offset=$offset&count=$count"
+      '/results/?output_mode='.$output_mode."&offset=$offset&count=$count"
    ) or return;
 
    my $code = $self->code;
@@ -141,7 +156,7 @@ sub search_jobs_sid_results {
    $self->debug && $self->log->debug("search_jobs_sid_results: content [".$resp->{content}."]");
 
    if ($code == 200) {  # Job finished
-      return $resp->{content}; # Return CSV content
+      return $self->content($output_mode);
    }
    elsif ($code == 204) {  # Job not finished
       return $self->log->error("search_jobs_sid_results: job not done");
@@ -150,20 +165,78 @@ sub search_jobs_sid_results {
    return $self->log->error("search_jobs_sid_results: failed with code [$code]");
 }
 
+#
+# http://docs.splunk.com/Documentation/Splunk/6.1.3/RESTAPI/RESTlicense
+#
 sub licenser_groups {
    my $self = shift;
 
-   my $uri = $self->uri;
-   $self->brik_help_set_undef_arg('licenser_groups', $uri) or return;
+   return $self->get('/services/licenser/groups');
+}
 
-   my $resp = $self->get($uri.'/services/licenser/groups') or return;
+#
+# curl -k -u admin https://localhost:8089/servicesNS/admin/$APP/data/lookup-table-files/$FILE.csv/acl -d owner=nobody -d sharing=global
+#
+# http://docs.splunk.com/Documentation/Splunk/6.1.3/RESTAPI/RESTknowledge
+#
+sub data_lookup_table_files_acl {
+   my $self = shift;
+   my ($app, $csv_file, $perm) = @_;
+
+   $perm ||= { owner => 'nobody', sharing => 'global' };
+   $self->brik_help_run_undef_arg('data_lookup_table_files_acl', $app) or return;
+   $self->brik_help_run_undef_arg('data_lookup_table_files_acl', $csv_file) or return;
+
+   my $uri = $self->uri;
+   my $username = $self->username;
+
+   if ($csv_file !~ m{\.csv$}) {
+      return $self->log->error("data_lookup_table_files_acl: csv file [$csv_file] must ends with .csv extension");
+   }
+
+   my $resp = $self->post(
+      $perm, $uri.'/servicesNS/'.$username.'/'.$app.'/data/lookup-table-files/'.$csv_file.'/acl'
+   ) or return;
 
    my $code = $self->code;
 
-   $self->log->verbose("licenser_groups: returned code [$code]");
-   $self->debug && $self->log->debug("licenser_groups: content [".$resp->{content}."]");
+   $self->log->verbose("data_lookup_table_files_acl: returned code [$code]");
+   $self->debug && $self->log->debug("data_lookup_table_files_acl: content [".$resp->{content}."]");
 
-   return $self->content;
+   return $self->content('xml');
+}
+
+sub cluser_config {
+   my $self = shift;
+
+   return $self->get('/services/cluster/config');
+}
+
+sub cluser_config_config {
+   my $self = shift;
+
+   return $self->get('/services/cluster/config/config');
+}
+
+sub deployment_client {
+   my $self = shift;
+
+   return $self->get('/services/deployment/client');
+}
+
+sub deployment_client_config {
+   my $self = shift;
+
+   return $self->get('/services/deployment/client/config');
+}
+
+sub search_data_lookuptablefiles {
+   my $self = shift;
+   my ($username) = @_;
+
+   $username ||= $self->username;
+
+   return $self->get('/servicesNS/'.$username.'/search/data/lookup-table-files');
 }
 
 1;
@@ -176,7 +249,7 @@ Metabrik::Api::Splunk - api::splunk Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
