@@ -1,5 +1,5 @@
 #
-# $Id: Cvesearch.pm,v fc658e60fb76 2016/10/08 15:24:49 gomor $
+# $Id: Cvesearch.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
 #
 # database::cvesearch Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: fc658e60fb76 $',
+      revision => '$Revision: f6ad8c136b19 $',
       tags => [ qw(unstable cve cpe vfeed circl) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -68,7 +68,15 @@ sub install {
    my $url = 'https://github.com/cve-search/cve-search';
 
    my $dg = Metabrik::Devel::Git->new_from_brik_init($self) or return;
-   my $repo = $dg->clone($url) or return;
+
+   my $repo = '';
+   my $datadir = $self->global->datadir;
+   if (-d "$datadir/devel-git/cve-search") {
+      $repo = $dg->update($url) or return;
+   }
+   else {
+      $repo = $dg->clone($url) or return;
+   }
 
    $self->sudo_execute('pip3 install -r '.$repo.'/requirements.txt') or return;
 
@@ -223,7 +231,7 @@ Metabrik::Database::Cvesearch - database::cvesearch Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
