@@ -1,5 +1,5 @@
 #
-# $Id: Write.pm,v 6681de14037f 2016/01/16 16:06:27 gomor $
+# $Id: Write.pm,v 1e1671f227f5 2017/01/05 17:29:15 gomor $
 #
 # file::write Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6681de14037f $',
+      revision => '$Revision: 1e1671f227f5 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -22,17 +22,24 @@ sub brik_properties {
          encoding => [ qw(utf8|ascii) ],
          fd => [ qw(file_descriptor) ],
          unbuffered => [ qw(0|1) ],
+         use_locking => [ qw(0|1) ],
       },
       attributes_default => {
          append => 1,
          overwrite => 0,
          unbuffered => 0,
+         use_locking => 0,
       },
       commands => {
          open => [ qw(file|OPTIONAL) ],
+         lock => [ ],
+         unlock => [ ],
          write => [ qw($data|$data_ref|$data_list) ],
          close => [ ],
       },
+      require_modules => {
+         Fcntl => [ qw(:flock) ],
+      },
    };
 }
 
@@ -100,6 +107,41 @@ sub close {
    return 1;
 }
 
+sub lock {
+   my $self = shift;
+
+   my $fd = $self->fd or return 1;
+
+   my $r = flock($fd, Fcntl::LOCK_EX());
+   if (! defined($r)) {
+      return $self->log->error("lock: flock: locking failed: $!");
+   }
+
+   $r = seek($fd, 0, Fcntl::SEEK_END());
+   if (! defined($r)) {
+      return $self->log->error("lock: seek: seeking failed: $!");
+   }
+
+   $self->log->debug("lock: locking fd");
+
+   return 1;
+}
+
+sub unlock {
+   my $self = shift;
+
+   my $fd = $self->fd or return 1;
+
+   my $r = flock($fd, Fcntl::LOCK_UN());
+   if (! defined($r)) {
+      return $self->log->error("lock: flock: unlocking failed: $!");
+   }
+
+   $self->log->debug("unlock: unlocking fd");
+
+   return 1;
+}
+
 sub write {
    my $self = shift;
    my ($data) = @_;
@@ -108,6 +150,10 @@ sub write {
    $self->brik_help_run_undef_arg('open', $fd) or return;
    $self->brik_help_run_undef_arg('write', $data) or return;
 
+   if ($self->use_locking) {
+      $self->lock or return;
+   }
+
    $self->debug && $self->log->debug("write: data[$data]");
 
    if (ref($data) eq 'ARRAY') {
@@ -119,6 +165,10 @@ sub write {
       ref($data) eq 'SCALAR' ? print $fd $$data : print $fd $data;
    }
 
+   if ($self->use_locking) {
+      $self->unlock or return;
+   }
+
    return $data;
 }
 
@@ -132,7 +182,7 @@ Metabrik::File::Write - file::write Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
