@@ -1,5 +1,5 @@
 #
-# $Id: Syslog.pm,v b5a7d96de9f1 2016/10/11 06:17:23 gomor $
+# $Id: Syslog.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
 #
 # log::syslog Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Core::Log);
 
 sub brik_properties {
    return {
-      revision => '$Revision: b5a7d96de9f1 $',
+      revision => '$Revision: f6ad8c136b19 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -76,6 +76,37 @@ sub brik_init {
    return $self->SUPER::brik_init;
 }
 
+sub message {
+   my $self = shift;
+   my ($text, $caller) = @_;
+
+   $text ||= 'undef';
+
+   # Convert to a string of key="value" pairs
+   if (ref($text) eq 'HASH') {
+      my $kv = '';
+      for my $k (sort { $a cmp $b } keys %$text) {
+         if ($k !~ m{\s}) {  # If there is no space char, we don't put between double quotes
+            $kv .= "$k=\"".$text->{$k}."\" ";
+         }
+         else {
+            $kv .= "\"$k\"=\"".$text->{$k}."\" ";
+         }
+      }
+      $kv =~ s{\s*$}{};
+      $text = $kv;
+   }
+
+   my $message = '';
+   if (defined($caller)) {
+      $caller =~ s/^metabrik:://i;
+      $caller = lc($caller);
+      $message .= lc($caller).': ';
+   }
+
+   return $message."$text\n";
+}
+
 sub send {
    my $self = shift;
    my ($msg, $priority) = @_;
@@ -218,7 +249,7 @@ Metabrik::Log::Syslog - log::syslog Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
