@@ -1,5 +1,5 @@
 #
-# $Id: Iplocation.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Iplocation.pm,v ffeabf04f880 2017/10/21 11:57:26 gomor $
 #
 # lookup::iplocation Brik
 #
@@ -11,12 +11,13 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: ffeabf04f880 $',
       tags => [ qw(unstable location ipv4 ipv6 ip geo geolocation) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
+         _na => [ qw(INTERNAL) ],
       },
       commands => {
          update => [ ],
@@ -34,9 +35,25 @@ sub brik_properties {
          'Metabrik::File::Compress' => [ ],
          'Metabrik::Network::Address' => [ ],
       },
+      need_packages => {
+         ubuntu => [ qw(libgeoip-dev) ],
+         debian => [ qw(libgeoip-dev) ],
+         freebsd => [ qw(net/GeoIP) ],
+      },
    };
 }
 
+sub brik_init {
+   my $self = shift;
+
+   my $init = $self->SUPER::brik_init or return;
+
+   my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
+   $self->_na($na);
+
+   return 1;
+}
+
 sub update {
    my $self = shift;
 
@@ -46,9 +63,11 @@ sub update {
 
    my %mirror = (
       'GeoIP.dat.gz' => 'GeoLiteCountry/GeoIP.dat.gz',
-      'GeoIPCity.dat.gz' => 'GeoLiteCity.dat.gz',
       'GeoIPv6.dat.gz' => 'GeoIPv6.dat.gz',
-      'GeoIPASNum.dat.gz' => 'asnum/GeoIPASNum.dat.gz'
+      'GeoLiteCity.dat.gz' => 'GeoLiteCity.dat.gz',
+      'GeoLiteCityv6.dat.gz' => 'GeoLiteCityv6-beta/GeoLiteCityv6.dat.gz',
+      'GeoIPASNum.dat.gz' => 'asnum/GeoIPASNum.dat.gz',
+      'GeoIPASNumv6.dat.gz' => 'asnum/GeoIPASNumv6.dat.gz',
    );
 
    my $cw = Metabrik::Client::Www->new_from_brik_init($self) or return;
@@ -78,10 +97,10 @@ sub from_ipv4 {
 
    $self->brik_help_run_undef_arg('from_ipv4', $ipv4) or return;
 
-   my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
+   my $na = $self->_na;
 
-   my $gi = Geo::IP->open($self->datadir.'/GeoIPCity.dat', Geo::IP::GEOIP_STANDARD())
-      or return $self->log->error("from_ipv4: unable to open GeoIPCity.dat");
+   my $gi = Geo::IP->open($self->datadir.'/GeoLiteCity.dat', Geo::IP::GEOIP_STANDARD())
+      or return $self->log->error("from_ipv4: unable to open GeoLiteCity.dat");
 
    my $gi_asn = Geo::IP->open($self->datadir.'/GeoIPASNum.dat', Geo::IP::GEOIP_STANDARD())
       or return $self->log->error("from_ipv4: unable to open GeoIPASNum.dat");
@@ -92,13 +111,23 @@ sub from_ipv4 {
    };
    if ($@ || ! defined($record)) {
       chomp($@);
-      return $self->log->error("from_ipv4: unable to find info for IPv4 [$ipv4] ".
-         "with error [$@]");
+      return $self->log->error("from_ipv4: unable to find info for IPv4 [$ipv4]");
    }
 
-   # Convert from blessed hashref to hashref
-   my $h = { map { $_ => $record->{$_} } keys %$record };
-   $h->{timezone} = $record->time_zone;
+   my $h = {};
+   $h->{country_code} = $record->country_code;
+   $h->{country_code3} = $record->country_code3;
+   $h->{country_name} = $record->country_name;
+   $h->{region} = $record->region;
+   $h->{region_name} = $record->region_name;
+   $h->{city} = $record->city;
+   $h->{postal_code} = $record->postal_code;
+   $h->{latitude} = $record->latitude;
+   $h->{longitude} = $record->longitude;
+   $h->{time_zone} = $record->time_zone;
+   $h->{area_code} = $record->area_code;
+   $h->{continent_code} = $record->continent_code;
+   $h->{metro_code} = $record->metro_code;
 
    my $asn = '';
    my $organization = '';
@@ -146,17 +175,78 @@ sub from_ipv6 {
 
    $self->brik_help_run_undef_arg('from_ipv6', $ipv6) or return;
 
-   # XXX: IPv6:
-   # my $gi = Geo::IP->open( "/usr/local/share/GeoIP/GeoIPASNumv6.dat", GEOIP_STANDARD );
-   # print $gi->name_by_addr_v6('::ffff:24.24.24.24') || '';
+   my $na = $self->_na;
 
-   my $gi = Geo::IP->open($self->datadir.'/GeoIPv6.dat')
-      or return $self->log->error("from_ipv6: unable to open GeoIPv6.dat");
+   my $gi = Geo::IP->open($self->datadir.'/GeoLiteCityv6.dat', Geo::IP::GEOIP_STANDARD())
+      or return $self->log->error("from_ipv6: unable to open GeoLiteCityv6.dat");
 
-   my $record = $gi->country_code_by_addr_v6($ipv6);
+   my $gi_asn = Geo::IP->open($self->datadir.'/GeoIPASNumv6.dat',
+      Geo::IP::GEOIP_STANDARD())
+         or return $self->log->error("from_ipv6: unable to open GeoIPASNumv6.dat");
 
-   # Convert from blessed hashref to hashref
-   return { map { $_ => $record->{$_} } keys %$record };
+   my $record;
+   eval {
+      $record = $gi->record_by_addr_v6($ipv6);
+   };
+   if ($@ || ! defined($record)) {
+      chomp($@);
+      return $self->log->error("from_ipv6: unable to find info for IPv6 [$ipv6]");
+   }
+
+   my $h = {};
+   $h->{country_code} = $record->country_code;
+   $h->{country_code3} = $record->country_code3;
+   $h->{country_name} = $record->country_name;
+   $h->{region} = $record->region;
+   $h->{region_name} = $record->region_name;
+   $h->{city} = $record->city;
+   $h->{postal_code} = $record->postal_code;
+   $h->{latitude} = $record->latitude;
+   $h->{longitude} = $record->longitude;
+   $h->{time_zone} = $record->time_zone;
+   $h->{area_code} = $record->area_code;
+   $h->{continent_code} = $record->continent_code;
+   $h->{metro_code} = $record->metro_code;
+
+   my $asn = '';
+   my $organization = '';
+   my $asn_organization = $gi_asn->name_by_addr_v6($ipv6);
+   if ($asn_organization) {
+      ($asn, $organization) = $asn_organization =~ m{^(\S+)(?:\s+(.*))?$};
+      $asn ||= $asn_organization;  # Not able to parse, we put it raw.
+   }
+   $asn ||= 'undef';
+   $organization ||= 'undef';
+
+   #my ($from, $to) = $gi->range_by_ip($ipv6);
+   #if (! defined($from) || ! defined($to)) {
+      #return $self->log->error("from_ipv6: unable to find range for IPv6 [$ipv6]");
+   #}
+
+   #my $network = $na->range_to_cidr($from, $to) or return;
+   my $network = [ 'undef' ]; # Not avail in IPv6 for now.
+   my $network_list = join('|', @$network);
+   $h->{first_ip} = 'undef';
+   $h->{last_ip} = 'undef';
+
+   # Add other info and return
+   $h->{asn} = $asn;
+   $h->{organization} = $organization;
+   $h->{networks} = $network_list;
+
+   # If not defined, we set to 0, as this should be a number.
+   $h->{dma_code} ||= 0;
+   $h->{area_code} ||= 0;
+   $h->{metro_code} ||= 0;
+
+   # Set as undef if nothing found
+   for my $k (keys %$h) {
+      if (! defined($h->{$k}) || ! length($h->{$k})) {
+         $h->{$k} = 'undef';
+      }
+   }
+
+   return $h;
 }
 
 sub from_ip {
@@ -165,7 +255,7 @@ sub from_ip {
 
    $self->brik_help_run_undef_arg('from_ip', $ip) or return;
 
-   my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
+   my $na = $self->_na;
    if ($na->is_ipv4($ip)) {
       return $self->from_ipv4($ip);
    }
@@ -184,8 +274,8 @@ sub subnet4 {
 
    $self->brik_help_run_undef_arg('subnet4', $ipv4_address) or return;
 
-   my $gi = Geo::IP->open($self->datadir.'/GeoIPCity.dat', Geo::IP::GEOIP_STANDARD())
-      or return $self->log->error("subnet4: unable to open GeoIPCity.dat");
+   my $gi = Geo::IP->open($self->datadir.'/GeoLiteCity.dat', Geo::IP::GEOIP_STANDARD())
+      or return $self->log->error("subnet4: unable to open GeoLiteCity.dat");
 
    my ($from, $to) = $gi->range_by_ip($ipv4_address);
 
@@ -198,8 +288,8 @@ sub organization_name {
 
    $self->brik_help_run_undef_arg('organization_name', $ip_address) or return;
   
-   my $gi = Geo::IP->open($self->datadir.'/GeoIPCity.dat', Geo::IP::GEOIP_STANDARD())
-      or return $self->log->error("organization_name: unable to open GeoIPCity.dat");
+   my $gi = Geo::IP->open($self->datadir.'/GeoLiteCity.dat', Geo::IP::GEOIP_STANDARD())
+      or return $self->log->error("organization_name: unable to open GeoLiteCity.dat");
 
    my $record = $gi->name_by_addr($ip_address);
 
@@ -212,8 +302,8 @@ sub range_from_ipv4 {
 
    $self->brik_help_run_undef_arg('range_from_ipv4', $ipv4) or return;
 
-   my $gi = Geo::IP->open($self->datadir.'/GeoIPCity.dat', Geo::IP::GEOIP_STANDARD())
-      or return $self->log->error("range_from_ipv4: unable to open GeoIPCity.dat");
+   my $gi = Geo::IP->open($self->datadir.'/GeoLiteCity.dat', Geo::IP::GEOIP_STANDARD())
+      or return $self->log->error("range_from_ipv4: unable to open GeoLiteCity.dat");
 
    my ($from, $to) = $gi->range_by_ip($ipv4);
 
@@ -228,7 +318,7 @@ sub networks_from_ipv4 {
 
    my $range = $self->range_from_ipv4($ipv4) or return;
 
-   my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
+   my $na = $self->_na;
 
    return $na->range_to_cidr($range->[0], $range->[1]);
 }
