@@ -1,5 +1,5 @@
 #
-# $Id: Elasticsearch.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Elasticsearch.pm,v 07eaa8bc26b2 2017/09/24 12:18:36 gomor $
 #
 # server::elasticsearch Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::System::Process);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 07eaa8bc26b2 $',
       tags => [ qw(unstable elk) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -21,7 +21,7 @@ sub brik_properties {
          port => [ qw(port) ],
          conf_file => [ qw(file) ],
          pidfile => [ qw(file) ],
-         version => [ qw(2.4.1|5.0.0) ],
+         version => [ qw(2.4.1|5.0.0|5.5.2) ],
          no_output => [ qw(0|1) ],
          cluster_name => [ qw(name) ],
          node_name => [ qw(name) ],
@@ -32,7 +32,7 @@ sub brik_properties {
       attributes_default => {
          listen => '127.0.0.1',
          port => 9200,
-         version => '5.0.0',
+         version => '5.5.2',
          no_output => 1,
          cluster_name => 'metabrik',
          node_name => 'metabrik-1',
@@ -120,11 +120,20 @@ sub generate_conf {
    $sf->mkdir($db_dir) or return;
    $sf->mkdir($log_dir) or return;
 
+   (my $path_conf = $conf_file) =~ s{/elasticsearch.yml$}{};
+
    my $conf =<<EOF
+#bootstrap.memory_lock: true
+node.master: true
+node.data: true
+node.ingest: true
 cluster.name: $cluster_name
 node.name: $node_name
+path.conf: $path_conf
 path.data: $db_dir
 path.logs: $log_dir
+discovery.zen.minimum_master_nodes: 1
+discovery.zen.ping.unicast.hosts: ["$listen"]
 network.bind_host: ["$listen"]
 network.publish_host: $listen
 http.port: $port
@@ -147,12 +156,15 @@ sub install {
    my $version = $self->version;
    my $she = $self->shell;
 
-   my $url = 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-5.0.0.tar.gz';
+   my $url = 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-5.5.2.tar.gz';
    if ($version eq '2.4.1') {
       $url = 'https://download.elastic.co/elasticsearch/release/org/'.
              'elasticsearch/distribution/tar/elasticsearch/2.4.1/'.
              'elasticsearch-2.4.1.tar.gz';
    }
+   elsif ($version eq '5.0.0') {
+      $url = 'https://artifacts.elastic.co/downloads/elasticsearch/elasticsearch-5.0.0.tar.gz';
+   }
 
    my $cw = Metabrik::Client::Www->new_from_brik_init($self) or return;
    $cw->mirror($url, "$datadir/es.tar.gz") or return;
