@@ -1,5 +1,5 @@
 #
-# $Id: Base64.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Base64.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
 #
 # string::base64 Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: f6ad8c136b19 $',
       tags => [ qw(unstable encode decode) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -31,7 +31,7 @@ sub encode {
 
    $self->brik_help_run_undef_arg('encode', $data) or return;
 
-   my $encoded = MIME::Base64::encode_base64($data);
+   my $encoded = MIME::Base64::encode_base64($data, '');
    chomp($encoded);
 
    return $encoded;
@@ -59,7 +59,7 @@ Metabrik::String::Base64 - string::base64 Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
