@@ -1,5 +1,5 @@
 #
-# $Id: Service.pm,v 2f5dc955ae51 2016/10/06 16:15:29 gomor $
+# $Id: Service.pm,v 94e85541d72a 2017/02/04 16:34:12 gomor $
 #
 # system::debian::service Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::System::Ubuntu::Service);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 2f5dc955ae51 $',
+      revision => '$Revision: 94e85541d72a $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -26,9 +26,10 @@ sub brik_properties {
       require_binaries => {
          'update-rc.d' => [ ],
       },
-      need_packages => {
-         debian => [ qw(sysv-rc) ],
-      },
+      #need_packages => {
+         #ubuntu => [ qw() ],
+         #debian => [ qw() ],
+      #},
    };
 }
 
@@ -42,7 +43,7 @@ Metabrik::System::Debian::Service - system::debian::service Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
