@@ -1,5 +1,5 @@
 #
-# $Id: Package.pm,v f43f03db50ed 2016/10/04 05:00:14 gomor $
+# $Id: Package.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
 #
 # system::package Brik
 #
@@ -7,11 +7,11 @@ package Metabrik::System::Package;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f43f03db50ed $',
+      revision => '$Revision: f6ad8c136b19 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -24,7 +24,9 @@ sub brik_properties {
          upgrade => [ qw(version|OPTIONAL) ],
          is_os => [ qw(os) ],
          is_os_ubuntu => [ ],
+         is_os_debian => [ ],
          is_os_freebsd => [ ],
+         is_os_centos => [ ],
          is_installed => [ qw(package|$package_list) ],
          my_os => [ ],
          which => [ qw(file) ],
@@ -34,7 +36,9 @@ sub brik_properties {
       require_modules => {
          'Metabrik::System::Os' => [ ],
          'Metabrik::System::Ubuntu::Package' => [ ],
+         'Metabrik::System::Debian::Package' => [ ],
          'Metabrik::System::Freebsd::Package' => [ ],
+         'Metabrik::System::Centos::Package' => [ ],
       },
    };
 }
@@ -43,17 +47,26 @@ sub get_system_package {
    my $self = shift;
 
    my $os = $self->my_os;
+   my $sudo_args = $self->sudo_args;
 
    my $sp;
    if ($os eq 'ubuntu') {
       $sp = Metabrik::System::Ubuntu::Package->new_from_brik_init($self) or return;
    }
+   elsif ($os eq 'debian') {
+      $sp = Metabrik::System::Debian::Package->new_from_brik_init($self) or return;
+   }
    elsif ($os eq 'freebsd') {
       $sp = Metabrik::System::Freebsd::Package->new_from_brik_init($self) or return;
    }
-   else {
-      return $self->log->error("get_system_package: cannot determine package system for OS [os]");
+   elsif ($os eq 'centos') {
+      $sp = Metabrik::System::Centos::Package->new_from_brik_init($self) or return;
    }
+   else {
+      return $self->log->error("get_system_package: cannot determine package system for OS [$os]");
+   }
+
+   $sp->sudo_args($sudo_args);
 
    return $sp;
 }
@@ -79,7 +92,8 @@ sub install {
       return $sp->install($package);
    }
    elsif (! exists($self->brik_properties->{need_packages})) {
-      return $self->log->error($self->brik_help_run('install'));
+      #return $self->log->error($self->brik_help_run('install'));
+      return 1;
    }
    else {
       my $os = $self->my_os;
@@ -162,12 +176,24 @@ sub is_os_ubuntu {
    return $self->is_os('ubuntu');
 }
 
+sub is_os_debian {
+   my $self = shift;
+
+   return $self->is_os('debian');
+}
+
 sub is_os_freebsd {
    my $self = shift;
 
    return $self->is_os('freebsd');
 }
 
+sub is_os_centos {
+   my $self = shift;
+
+   return $self->is_os('centos');
+}
+
 sub is_installed {
    my $self = shift;
    my ($package) = @_;
@@ -209,7 +235,7 @@ Metabrik::System::Package - system::package Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
