@@ -1,5 +1,5 @@
 #
-# $Id: Service.pm,v fc658e60fb76 2016/10/08 15:24:49 gomor $
+# $Id: Service.pm,v 94e85541d72a 2017/02/04 16:34:12 gomor $
 #
 # system::ubuntu::service Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: fc658e60fb76 $',
+      revision => '$Revision: 94e85541d72a $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -26,10 +26,10 @@ sub brik_properties {
       require_binaries => {
          'update-rc.d' => [ ],
       },
-      need_packages => {
-         ubuntu => [ qw(sysv-rc) ],
-         debian => [ qw(sysv-rc) ],
-      },
+      #need_packages => {
+         #ubuntu => [ qw() ],
+         #debian => [ qw() ],
+      #},
    };
 }
 
@@ -65,7 +65,7 @@ Metabrik::System::Ubuntu::Service - system::ubuntu::service Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
