@@ -1,5 +1,5 @@
 #
-# $Id: Google.pm,v b5a7d96de9f1 2016/10/11 06:17:23 gomor $
+# $Id: Google.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
 #
 # www::google Brik
 #
@@ -11,18 +11,20 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: b5a7d96de9f1 $',
+      revision => '$Revision: f6ad8c136b19 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          language => [ qw(fr|uk|de|ch) ],
          page => [ qw(number) ],
+         filter => [ qw(0|1) ],
       },
       attributes_default => {
          language => 'fr',
          page => 1,
          do_javascript => 1,
+         filter => 0,
       },
       commands => {
          search => [ qw(keywords) ],
@@ -54,6 +56,7 @@ sub search {
 
    my $language = $self->language;
    my $page = $self->page;
+   my $filter = $self->filter;
 
    my $keywords = join(' ', @args);
 
@@ -84,7 +87,7 @@ sub search {
       $start = 0;
    }
    $start *= 10;
-   my $search = $url.$keywords.'&start='.$start;
+   my $search = $url.$keywords.'&start='.$start.'&filter='.$filter;
 
    $self->log->verbose("search: [$search]");
 
@@ -132,7 +135,7 @@ sub _traverse {
          my $tag = $this->tag;
          if ($tag eq 'a') {
             my $h = $self->_href_to_hash($this);
-            if ($h) {
+            if ($h && keys %$h > 0) {
                #print Data::Dumper::Dumper($h)."\n";
                push @results, $h;
             }
@@ -153,6 +156,7 @@ sub _href_to_hash {
    my ($element) = @_;
 
    # /url?q=http://www.justanswer.com/military-law/5ps6l-read-gomor-submitted-rebuttal-go-will.html&sa=U&ved=0ahUKEwi_hP_LgJTPAhVEWRoKHdlaDKQQFghHMAk&usg=AFQjCNGs50hYJHY-aJ6yxYeiP0p5Qd52-A
+   my $is_incomplete = 0;
    my $title = '';
    my $url = '';
    my $href = $element->{href};
@@ -163,8 +167,13 @@ sub _href_to_hash {
       my @list = @{$element->content};
       for (@list) {
          if (ref($_) eq 'HTML::Element') {
-            my $txt = join(' ', @{$_->content});
-            $title .= $txt;
+            if (defined($_->content)) {
+               my $txt = join(' ', @{$_->content});
+               $title .= $txt;
+            }
+            else {
+               return {};
+            }
          }
          else {
             $title .= $_;
@@ -197,7 +206,7 @@ Metabrik::Www::Google - www::google Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
